==> prestashop_1.4.2.5.zip: prestashop/modules/ebay/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ebay}prestashop>ebay_282539987a2276dd5259f8e745d668a1'] = 'eBay';
$_MODULE['<{ebay}prestashop>ebay_1179327c010f54ade46baea3c3b0ceec'] = 'Ouvrez votre boutique pro sur la place de marché eBay !';
$_MODULE['<{ebay}prestashop>ebay_6fecf5a008d74051f0e8aae985b37aa6'] = 'Le module eBay ne fonctionne actuellement que pour eBay.fr';
$_MODULE['<{ebay}prestashop>ebay_7f1d3dc2e00e30a574dbdf2ac7f0304e'] = 'Class cURL';
$_MODULE['<{ebay}prestashop>ebay_4d470fde8487e755a50e9235e3dc13ab'] = 'doivent être configurés pour que le module fonctionne correctement.';
$_MODULE['<{ebay}prestashop>ebay_2e4f4d8b849fb72905addc231d160e8b'] = 'Status du module eBay';
$_MODULE['<{ebay}prestashop>ebay_85f9d92e0551772437b934b7222d63cb'] = 'Le module eBay est fonctionnel.';
$_MODULE['<{ebay}prestashop>ebay_090bcb46805aadf384074d380b4c78c8'] = 'Le module eBay n\'est pas encore configuré.';
$_MODULE['<{ebay}prestashop>ebay_9a5c99bf25e84cd8fe7c500f7ec698f2'] = 'Enregistrer le module sur eBay';
$_MODULE['<{ebay}prestashop>ebay_f09ea5dca3d187c50a634239778a5a3c'] = 'Activer \"Allow url fopen\"';
$_MODULE['<{ebay}prestashop>ebay_c7760f2c36d4e647e8a254cef51cbae8'] = 'Activer cURL';
$_MODULE['<{ebay}prestashop>ebay_16bfbf9c462762cf1cba4134ec53c504'] = 'Chargement';
$_MODULE['<{ebay}prestashop>ebay_1855841a23ac9c36ec603454a0c273a6'] = 'Une fois identifié dans la fenêtre eBay, le module finira automatiquement l\'installation dans les secondes qui suivent.';
$_MODULE['<{ebay}prestashop>ebay_d9334a0c5b4432b2ad87fb9c90e9f44c'] = 'Vous devez renseigner votre Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_4285b577739883af893c3b1320690b70'] = 'Cliquez sur le bouton ci-dessous';
$_MODULE['<{ebay}prestashop>ebay_7ba7cc1dfb00eca77b600084f4ba1304'] = 'Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_3225a10b07f1580f10dee4abc3779e6c'] = 'Paramètres';
$_MODULE['<{ebay}prestashop>ebay_dc2f736ed903b4f6f72a36b763cd7717'] = 'Configuration des catégories';
$_MODULE['<{ebay}prestashop>ebay_0f5f872ba4c6575319e6beee6ebcc481'] = 'Template de la fiche produit';
$_MODULE['<{ebay}prestashop>ebay_47ba6504eb5b1e3a95ea3dbd960904db'] = 'Mise en ligne des produits';
$_MODULE['<{ebay}prestashop>ebay_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{ebay}prestashop>ebay_e5beb503fe9553f0ed5be3c324fc9cb7'] = 'Pour exporter vos produits sur eBay, vous devez créer un compte pro sur eBay (voir la partie Aide) et configurer le module eBay-Prestashop.';
$_MODULE['<{ebay}prestashop>ebay_230b8b5e65ef7731d72a42b1ddb0293f'] = 'Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_ad44bf098615279532ded210754420d4'] = 'Voir vos produits sur eBay';
$_MODULE['<{ebay}prestashop>ebay_5d8ae2a94331ebbfe854eea0274e939c'] = 'Votre identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_4b9f5155cc88fe352fbf202a3ba57f04'] = 'Boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_3e0fb5fcfe85cdf0f83fefe3530d13f4'] = 'Votre boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_97b4fc969316e8d08c1b0bb1f0b05fbd'] = 'Voir votre boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_1734acc41e3889028ca0f0d13ef5bc93'] = 'Votre identifiant PayPal (email)';
$_MODULE['<{ebay}prestashop>ebay_45eea1d5baed190ff1c6db538516f7c3'] = 'Vous devez renseigner votre e-mail de compte Paypal, c\'est le seul moyen de paiement disponible avec ce module.';
$_MODULE['<{ebay}prestashop>ebay_83d893ae1e34a74ab9a068e1d190c764'] = 'Moyen d’expédition';
$_MODULE['<{ebay}prestashop>ebay_3d346df981cf71d3a81b57c1af58f1f4'] = 'Frais de livraison pour les produits sur eBay';
$_MODULE['<{ebay}prestashop>ebay_552a0d8c17d95d5dbdc0c28217024f5a'] = 'Frais de livraison';
$_MODULE['<{ebay}prestashop>ebay_ce178f4fe9684e5786aff36ab3cf81f6'] = 'Votre code postal';
$_MODULE['<{ebay}prestashop>ebay_8f6fa0b72376c388d15c877e9efb558a'] = 'Votre code postal';
$_MODULE['<{ebay}prestashop>ebay_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{ebay}prestashop>ebay_153e4104f5a42e006735dd85847760b1'] = 'Chargement des catégories';
$_MODULE['<{ebay}prestashop>ebay_3ce2048f8a2c26aff75c1fcf67774053'] = 'Votre identifiant eBay n\'est pas spécifié ou est invalide.';
$_MODULE['<{ebay}prestashop>ebay_c4df1be45decccecb07e960c2ae73bfe'] = 'Votre e-mail de compte Paypal n\'est pas spécifié ou est invalide.';
$_MODULE['<{ebay}prestashop>ebay_2d43e5106de30dfee1d333f0e26c484e'] = 'Vos frais de port ne sont spécifiés ou sont invalides.';
$_MODULE['<{ebay}prestashop>ebay_cb096ff53051ae8a8738ad9a4932c81e'] = 'Votre code postal n\'est pas spécifié ou est invalide';
$_MODULE['<{ebay}prestashop>ebay_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{ebay}prestashop>ebay_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuration non mise à jour.';
$_MODULE['<{ebay}prestashop>ebay_67e19ffdaa0a11e69349810403a9727e'] = 'Vous devez configurer l\'onglet \"Paramètres\" avant d\'utiliser cet onglet.';
$_MODULE['<{ebay}prestashop>ebay_5510e1a031c7c2700dfc34ecb6e39cca'] = 'Pour mettre en ligne vos produits sur eBay, vous devez associer chacune des catégories de votre boutique à une catégorie eBay. Vous pouvez également définir une variation du prix sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_1bffdb0b10182ea51f7baa97ee2d19a8'] = 'Vous pouvez utiliser le bouton ci-dessous pour associer automatiquement les catégories qui n\'ont pas encore d\'association avec des catégories suggérées par eBay.';
$_MODULE['<{ebay}prestashop>ebay_36be9eda23888bf12f74d6cd9d46ba1d'] = 'Suggérer des catégories';
$_MODULE['<{ebay}prestashop>ebay_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{ebay}prestashop>ebay_649829dea8fe9632cc51a9aa3c8826c3'] = 'Catégorie eBay';
$_MODULE['<{ebay}prestashop>ebay_233c543a23378c4ffd0e1efb17408510'] = 'Impact sur le prix';
$_MODULE['<{ebay}prestashop>ebay_a5612305bb46e3d0ea547f4a963a01d3'] = 'Aucune catégorie trouvée';
$_MODULE['<{ebay}prestashop>ebay_55ac32003f11f511412875f283f4f303'] = 'Aucune catégorie selectionnée';
$_MODULE['<{ebay}prestashop>ebay_549454516da11bb8fa2d28b04b5aaca6'] = 'Vous pouvez personnaliser le thème graphique de vos produit sur eBay';
$_MODULE['<{ebay}prestashop>ebay_1cbd8f2b57c85344f755caff03336306'] = 'Synchroniser avec eBay';
$_MODULE['<{ebay}prestashop>ebay_86024cad1e83101d97359d7351051156'] = 'produits';
$_MODULE['<{ebay}prestashop>ebay_05aaf6b3c49c3aa6219a1d730ee7988c'] = 'Vous allez maintenant mettre en ligne vos produits sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_3205b263a1a779c2b03cdbac836346f9'] = 'Pour rappel,';
$_MODULE['<{ebay}prestashop>ebay_0eaf4172db11a5d6e914aabe920f0455'] = 'vous ne payez aucun frais d’insertion si vous avez une boutique sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_25740d6b53eafdd8a64299e1fe92f247'] = 'Choix des produits à mettre en ligne';
$_MODULE['<{ebay}prestashop>ebay_97855df0367fedf5648d745bfb57412b'] = 'Option A';
$_MODULE['<{ebay}prestashop>ebay_2c53ffc482419e404cd47559e5004b2e'] = 'mettre 100% de vos produits en ligne sur eBay (recommandé)';
$_MODULE['<{ebay}prestashop>ebay_8890755ccd5ac4f777efdd0a6c16c4ab'] = 'Option B';
$_MODULE['<{ebay}prestashop>ebay_4ac5ebfcb9b9d8c87e9ff03ee6bf24e5'] = 'choisir les catégories à mettre en ligne sur eBay';
$_MODULE['<{ebay}prestashop>ebay_e0626222614bdee31951d84c64e5e9ff'] = 'Sélection';
$_MODULE['<{ebay}prestashop>ebay_caab0e2c2f3ae0d242b0b36f22d9acc5'] = 'Vous allez mettre en ligne';
$_MODULE['<{ebay}prestashop>ebay_70b240eb3db5174e1c9520cabe2ae781'] = 'produits sur eBay. Voulez-vous confirmer ?';
$_MODULE['<{ebay}prestashop>ebay_6d371302939f2bba5daf55544efb956f'] = 'Attention ! Si certaines de vos catégories ne sont pas compatibles multi sku, certains de vos produits peuvent créer plus d\'une fiche produit sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_054b4f3ea543c990f6b125f41af6ebf7'] = 'Option';
$_MODULE['<{ebay}prestashop>ebay_547c708291fe196592dd1e4db7b206a5'] = 'produit(s) mis en ligne sur eBay';

==> prestashop_1.4.4.1.zip: prestashop/modules/ebay/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ebay}prestashop>ebay_282539987a2276dd5259f8e745d668a1'] = 'eBay';
$_MODULE['<{ebay}prestashop>ebay_1179327c010f54ade46baea3c3b0ceec'] = 'Ouvrez votre boutique pro sur la place de marché eBay !';
$_MODULE['<{ebay}prestashop>ebay_6fecf5a008d74051f0e8aae985b37aa6'] = 'Le module eBay ne fonctionne actuellement que pour eBay.fr';
$_MODULE['<{ebay}prestashop>ebay_8acabcc788c316f92b7850c76265b49b'] = 'Vous devez activer l\'extension cURL et l\'option allow_url_fopen sur votre serveur si vous désirez utiliser ce module.';
$_MODULE['<{ebay}prestashop>ebay_d591cbc447d01e5a6165096ebfdf804e'] = 'Vous devez activer l\'extension cURL sur votre serveur si vous désirez utiliser ce module.';
$_MODULE['<{ebay}prestashop>ebay_1b18bd5d9d85f4f667614345ee20e3b2'] = 'Vous devez activer l\'option allow_url_fopen sur votre serveur si vous désirez utiliser ce module.';
$_MODULE['<{ebay}prestashop>ebay_8e64bc164aee46723ed2d70273c6f8ab'] = 'Vous devez enregistrer le module sur eBay';
$_MODULE['<{ebay}prestashop>ebay_98f54d8bba6523829eeb8fd7ab9a2088'] = 'Continuer quand même ?';
$_MODULE['<{ebay}prestashop>ebay_2e4f4d8b849fb72905addc231d160e8b'] = 'Status du module eBay';
$_MODULE['<{ebay}prestashop>ebay_85f9d92e0551772437b934b7222d63cb'] = 'Le module eBay est fonctionnel.';
$_MODULE['<{ebay}prestashop>ebay_090bcb46805aadf384074d380b4c78c8'] = 'Le module eBay n\'est pas encore configuré.';
$_MODULE['<{ebay}prestashop>ebay_9a5c99bf25e84cd8fe7c500f7ec698f2'] = 'Enregistrer le module sur eBay';
$_MODULE['<{ebay}prestashop>ebay_f09ea5dca3d187c50a634239778a5a3c'] = 'Activer \"Allow url fopen\"';
$_MODULE['<{ebay}prestashop>ebay_c7760f2c36d4e647e8a254cef51cbae8'] = 'Activer cURL';
$_MODULE['<{ebay}prestashop>ebay_16bfbf9c462762cf1cba4134ec53c504'] = 'Chargement';
$_MODULE['<{ebay}prestashop>ebay_b383064f397ca4f9de45a6dadc6a07a1'] = 'Une fois identifié dans la fenêtre eBay, le module finira automatiquement l\'installation dans les secondes qui suivent.';
$_MODULE['<{ebay}prestashop>ebay_d9334a0c5b4432b2ad87fb9c90e9f44c'] = 'Vous devez renseigner votre Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_4285b577739883af893c3b1320690b70'] = 'Cliquez sur le bouton ci-dessous';
$_MODULE['<{ebay}prestashop>ebay_7ba7cc1dfb00eca77b600084f4ba1304'] = 'Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_3225a10b07f1580f10dee4abc3779e6c'] = 'Paramètres';
$_MODULE['<{ebay}prestashop>ebay_dc2f736ed903b4f6f72a36b763cd7717'] = 'Configuration des catégories';
$_MODULE['<{ebay}prestashop>ebay_0f5f872ba4c6575319e6beee6ebcc481'] = 'Template de la fiche produit';
$_MODULE['<{ebay}prestashop>ebay_47ba6504eb5b1e3a95ea3dbd960904db'] = 'Mise en ligne des produits';
$_MODULE['<{ebay}prestashop>ebay_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{ebay}prestashop>ebay_e5beb503fe9553f0ed5be3c324fc9cb7'] = 'Pour exporter vos produits sur eBay, vous devez créer un compte pro sur eBay (voir la partie Aide) et configurer le module eBay-Prestashop.';
$_MODULE['<{ebay}prestashop>ebay_230b8b5e65ef7731d72a42b1ddb0293f'] = 'Identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_ad44bf098615279532ded210754420d4'] = 'Voir vos produits sur eBay';
$_MODULE['<{ebay}prestashop>ebay_5d8ae2a94331ebbfe854eea0274e939c'] = 'Votre identifiant eBay';
$_MODULE['<{ebay}prestashop>ebay_4b9f5155cc88fe352fbf202a3ba57f04'] = 'Boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_3e0fb5fcfe85cdf0f83fefe3530d13f4'] = 'Votre boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_97b4fc969316e8d08c1b0bb1f0b05fbd'] = 'Voir votre boutique eBay';
$_MODULE['<{ebay}prestashop>ebay_1734acc41e3889028ca0f0d13ef5bc93'] = 'Votre identifiant PayPal (email)';
$_MODULE['<{ebay}prestashop>ebay_4883ffdb0b673bdd200f3d96709c26f5'] = 'Vous devez renseigner votre e-mail de compte PayPal, c\'est le seul moyen de paiement disponible avec ce module.';
$_MODULE['<{ebay}prestashop>ebay_83d893ae1e34a74ab9a068e1d190c764'] = 'Moyen d’expédition';
$_MODULE['<{ebay}prestashop>ebay_3d346df981cf71d3a81b57c1af58f1f4'] = 'Frais de livraison pour les produits sur eBay';
$_MODULE['<{ebay}prestashop>ebay_552a0d8c17d95d5dbdc0c28217024f5a'] = 'Frais de livraison';
$_MODULE['<{ebay}prestashop>ebay_ce178f4fe9684e5786aff36ab3cf81f6'] = 'Votre code postal';
$_MODULE['<{ebay}prestashop>ebay_bb9a2f66fc726c85e45c8ddc93297ab9'] = 'Votre code postal';
$_MODULE['<{ebay}prestashop>ebay_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{ebay}prestashop>ebay_153e4104f5a42e006735dd85847760b1'] = 'Chargement des catégories';
$_MODULE['<{ebay}prestashop>ebay_123b3c98806c47a9bfa5fc7480e5327b'] = 'Votre identifiant eBay n\'est pas spécifié ou est invalide.';
$_MODULE['<{ebay}prestashop>ebay_179d471a6a534b682050411984ea1c05'] = 'Votre e-mail de compte Paypal n\'est pas spécifié ou est invalide.';
$_MODULE['<{ebay}prestashop>ebay_d0f2d9c05a3140a5fc81fd0cb6b330e2'] = 'Vos frais de port ne sont spécifiés ou sont invalides.';
$_MODULE['<{ebay}prestashop>ebay_458d329d5eb1caf63615141fb51e8329'] = 'Votre code postal n\'est pas spécifié ou est invalide';
$_MODULE['<{ebay}prestashop>ebay_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{ebay}prestashop>ebay_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuration non mise à jour.';
$_MODULE['<{ebay}prestashop>ebay_67e19ffdaa0a11e69349810403a9727e'] = 'Vous devez configurer l\'onglet \"Paramètres\" avant d\'utiliser cet onglet.';
$_MODULE['<{ebay}prestashop>ebay_1fe6b0032a7882ef20d08a5386441e33'] = 'Pour mettre en ligne vos produits sur eBay, vous devez associer chacune des catégories de votre boutique à une catégorie eBay. Vous pouvez également définir une variation du prix sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_1bffdb0b10182ea51f7baa97ee2d19a8'] = 'Vous pouvez utiliser le bouton ci-dessous pour associer automatiquement les catégories qui n\'ont pas encore d\'association avec des catégories suggérées par eBay.';
$_MODULE['<{ebay}prestashop>ebay_36be9eda23888bf12f74d6cd9d46ba1d'] = 'Suggérer des catégories';
$_MODULE['<{ebay}prestashop>ebay_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{ebay}prestashop>ebay_649829dea8fe9632cc51a9aa3c8826c3'] = 'Catégorie eBay';
$_MODULE['<{ebay}prestashop>ebay_233c543a23378c4ffd0e1efb17408510'] = 'Impact sur le prix';
$_MODULE['<{ebay}prestashop>ebay_a5612305bb46e3d0ea547f4a963a01d3'] = 'Aucune catégorie trouvée';
$_MODULE['<{ebay}prestashop>ebay_55ac32003f11f511412875f283f4f303'] = 'Aucune catégorie selectionnée';
$_MODULE['<{ebay}prestashop>ebay_628b583852257bd453a9a2c38a65fd6e'] = 'Attention : Seuls les catégories par défaut des produits sont pris en compte par cette configuration.';
$_MODULE['<{ebay}prestashop>ebay_6c09b50ba3b52d0d61fb785adeed1895'] = 'Vous pouvez personnaliser le thème graphique de vos produit sur eBay';
$_MODULE['<{ebay}prestashop>ebay_c01f01fd2bd607cf17ddc2ee584227f8'] = 'Vous devez configurer l\'onglet \"Configuration des catégories\" avant d\'utiliser cet onglet.';
$_MODULE['<{ebay}prestashop>ebay_1cbd8f2b57c85344f755caff03336306'] = 'Synchroniser avec eBay';
$_MODULE['<{ebay}prestashop>ebay_86024cad1e83101d97359d7351051156'] = 'produits';
$_MODULE['<{ebay}prestashop>ebay_05aaf6b3c49c3aa6219a1d730ee7988c'] = 'Vous allez maintenant mettre en ligne vos produits sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_3205b263a1a779c2b03cdbac836346f9'] = 'Pour rappel,';
$_MODULE['<{ebay}prestashop>ebay_0eaf4172db11a5d6e914aabe920f0455'] = 'vous ne payez aucun frais d’insertion si vous avez une boutique sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_25740d6b53eafdd8a64299e1fe92f247'] = 'Choix des produits à mettre en ligne';
$_MODULE['<{ebay}prestashop>ebay_97855df0367fedf5648d745bfb57412b'] = 'Option A';
$_MODULE['<{ebay}prestashop>ebay_2c53ffc482419e404cd47559e5004b2e'] = 'mettre 100% de vos produits en ligne sur eBay (recommandé)';
$_MODULE['<{ebay}prestashop>ebay_8890755ccd5ac4f777efdd0a6c16c4ab'] = 'Option B';
$_MODULE['<{ebay}prestashop>ebay_4ac5ebfcb9b9d8c87e9ff03ee6bf24e5'] = 'choisir les catégories à mettre en ligne sur eBay';
$_MODULE['<{ebay}prestashop>ebay_054b4f3ea543c990f6b125f41af6ebf7'] = 'Option';
$_MODULE['<{ebay}prestashop>ebay_892db3f832f6fe1a2d04e1e50e65d3ca'] = 'Lorsqu\'un produit est mis à jour, seule sa quantité et son prix sont resynchronisés avec eBay';
$_MODULE['<{ebay}prestashop>ebay_e0626222614bdee31951d84c64e5e9ff'] = 'Sélection';
$_MODULE['<{ebay}prestashop>ebay_caab0e2c2f3ae0d242b0b36f22d9acc5'] = 'Vous allez mettre en ligne';
$_MODULE['<{ebay}prestashop>ebay_70b240eb3db5174e1c9520cabe2ae781'] = 'produits sur eBay. Voulez-vous confirmer ?';
$_MODULE['<{ebay}prestashop>ebay_6d371302939f2bba5daf55544efb956f'] = 'Attention ! Si certaines de vos catégories ne sont pas compatibles multi sku, certains de vos produits peuvent créer plus d\'une fiche produit sur eBay.';
$_MODULE['<{ebay}prestashop>ebay_547c708291fe196592dd1e4db7b206a5'] = 'produit(s) mis en ligne sur eBay';
$_MODULE['<{ebay}prestashop>ebay_1761efb946aa43c14af989665dae691a'] = 'Produit(s) concerné(s)';
